@@ -29,10 +29,17 @@ pub mod error;
 /// hRPC socket used for streaming RPCs.
 pub mod socket;
 
+#[doc(hidden)]
+pub mod prelude {
+    pub use super::{error::ClientResult, socket::Socket, Client, HttpClient};
+    pub use crate::{exports::http::Uri, IntoRequest, Request};
+    pub use std::{convert::TryInto, fmt::Debug};
+}
+
 /// A `hyper` HTTP client that supports HTTPS.
 pub type HttpClient = hyper::Client<hyper_rustls::HttpsConnector<hyper::client::HttpConnector>>;
 
-/// Creates a new HttpClient that you can use.
+/// Creates a new [`HttpClient`] that you can use.
 pub fn http_client() -> HttpClient {
     let connector = hyper_rustls::HttpsConnector::with_native_roots();
     hyper::Client::builder().build(connector)
